/********************************************************************************
*                                                                               *
* xfspin.h   WOSA/XFS - Personal Identification Number Keypad (PIN) definitions *
*                                                                               *
*            Version 1.11  --  3 Feb 1995                                       *
*                                                                               *
********************************************************************************/
 
#ifndef __INC_XFSPIN__H
#define __INC_XFSPIN__H

#ifdef __cplusplus
extern "C" {
#endif

#include <xfsapi.h>

/*   be aware of alignment   */
#pragma pack(push,1)


/* values of WFSPINCAPS.wClass */

#define		WFS_SERVICE_CLASS_PIN			(4)

#define		PIN_SERVICE_OFFSET			(WFS_SERVICE_CLASS_PIN * 100)

/* PIN Info Commands */

#define		WFS_INF_PIN_STATUS			(PIN_SERVICE_OFFSET + 1)
#define		WFS_INF_PIN_CAPABILITIES		(PIN_SERVICE_OFFSET + 2)
#define		WFS_INF_PIN_KEY_DETAIL			(PIN_SERVICE_OFFSET + 4)

/* PIN Command Verbs */

#define 		WFS_CMD_PIN_CRYPT				(PIN_SERVICE_OFFSET + 1)
#define		WFS_CMD_PIN_GENERATE_KEY		(PIN_SERVICE_OFFSET + 2)
#define		WFS_CMD_PIN_IMPORT_KEY			(PIN_SERVICE_OFFSET + 3)
#define		WFS_CMD_PIN_GET_PIN			(PIN_SERVICE_OFFSET + 5)
#define		WFS_CMD_PIN_VALIDATE			(PIN_SERVICE_OFFSET + 6)
#define		WFS_CMD_PIN_GET_PINBLOCK		(PIN_SERVICE_OFFSET + 7)
#define		WFS_CMD_PIN_GET_DATA			(PIN_SERVICE_OFFSET + 8)
#define		WFS_CMD_PIN_INITIALIZATION		(PIN_SERVICE_OFFSET + 9)
#define		WFS_CMD_PIN_DISPLAY			(PIN_SERVICE_OFFSET + 10)

/* PIN Messages */

#define		WFS_EXEE_PIN_DIGIT			(PIN_SERVICE_OFFSET + 1)

/* values of WFSPINSTATUS.fwDevice */

#define		WFS_PIN_DEVONLINE				(0)
#define		WFS_PIN_DEVOFFLINE			(1)
#define		WFS_PIN_DEVPOWEROFF			(2)
#define		WFS_PIN_DEVBUSY				(3)
#define		WFS_PIN_DEVNODEVICE			(4)
#define		WFS_PIN_DEVHWERROR			(5)
#define		WFS_PIN_DEVUSERERROR			(6)

/* values of WFSPINSTATUS.fwEncStat */

#define		WFS_PIN_ENCREADY				(0)
#define		WFS_PIN_ENCNOTREADY			(1)
#define		WFS_PIN_ENCNOTINITIALIZED		(2)
#define		WFS_PIN_ENCBUSY				(3)
#define		WFS_PIN_ENCUNDEFINED			(4)
#define		WFS_PIN_ENCINITIALIZED			(5)

/* values of WFSPINCAPS.wType */

#define		WFS_PIN_TYPEEPP				(0)
#define		WFS_PIN_TYPEEDM				(1)

/* values of WFSPINCAPS.wAlgorithms, WFSPINCRYPT.wAlgorithm */

#define		WFS_PIN_CRYPTDESECB			0x0001
#define		WFS_PIN_CRYPTDESCBC			0x0002
#define		WFS_PIN_CRYPTDESCFB			0x0004
#define		WFS_PIN_CRYPTRSA				0x0008
#define		WFS_PIN_CRYPTECMA				0x0010
#define		WFS_PIN_CRYPTDESMAC			0x0020

/* values of WFSPINCAPS.wPinFormats */

#define		WFS_PIN_FORM3624				0x0001
#define		WFS_PIN_FORMANSI				0x0002
#define		WFS_PIN_FORMISO0				0x0004
#define		WFS_PIN_FORMISO1				0x0008
#define		WFS_PIN_FORMECI2				0x0010
#define		WFS_PIN_FORMECI3				0x0020
#define		WFS_PIN_FORMVISA				0x0040
#define		WFS_PIN_FORMDIEBOLD			0x0080

/* values of WFSPINCAPS.wDisplay */

#define		WFS_PIN_DISPNONE				(1)
#define		WFS_PIN_DISPLEDTHROUGH			(2)
#define		WFS_PIN_DISPDISPLAY			(3)

/* values of WFSPINCAPS.wKeyType */

#define		WFS_PIN_KEYNUMERIC			(0)
#define		WFS_PIN_KEYALPHANUMERIC			(1)

/* values of WFSPINKEYDETAIL.fwUse */

#define		WFS_PIN_USECRYPT				0x0001
#define		WFS_PIN_USEFUNCTION			0x0002
#define		WFS_PIN_USEMACING				0x0004
#define		WFS_PIN_USENOIMPORT			0x0010
#define		WFS_PIN_USEKEYENCKEY			0x0020
#define		WFS_PIN_USENODUPLICATE			0x0040

/* values of WFSPINKEYDETAIL.wStatus */

#define		WFS_PIN_KEYLOADED				(0)
#define		WFS_PIN_KEYNOVALUE			(1)

/* values of WFSPINCRYPT.wMode */

#define		WFS_PIN_MODEENCRYPT			(1)
#define		WFS_PIN_MODEDECRYPT			(2)

/* values of WFSPINENTRY.wCompletion */

#define		WFS_PIN_COMPAUTO				(0)
#define		WFS_PIN_COMPENTER				(1)
#define		WFS_PIN_COMPCANCEL			(2)
#define		WFS_PIN_COMPZERO				(3)
#define		WFS_PIN_COMPMAXLEN			(4)
#define		WFS_PIN_COMPMINLEN			(5)
#define		WFS_PIN_COMPCONTINUE			(6)
#define		WFS_PIN_COMPCORRECT			(7)
#define		WFS_PIN_COMPBACKSPACE			(8)


/* WOSA/XFS PIN Errors */ 

#define	WFS_ERR_PIN_KEYNOTFOUND			(-(PIN_SERVICE_OFFSET + 0))
#define	WFS_ERR_PIN_MODENOTSUPPORTED		(-(PIN_SERVICE_OFFSET + 1))
#define	WFS_ERR_PIN_ACCESSDENIED		(-(PIN_SERVICE_OFFSET + 2))
#define	WFS_ERR_PIN_INVALIDID			(-(PIN_SERVICE_OFFSET + 3))
#define	WFS_ERR_PIN_DUPLICATEKEY		(-(PIN_SERVICE_OFFSET + 4))
#define	WFS_ERR_PIN_INVALIDFORM			(-(PIN_SERVICE_OFFSET + 5))
#define	WFS_ERR_PIN_KEYNOVALUE			(-(PIN_SERVICE_OFFSET + 6))
#define	WFS_ERR_PIN_USEVIOLATION		(-(PIN_SERVICE_OFFSET + 7))
#define	WFS_ERR_PIN_NOPIN				(-(PIN_SERVICE_OFFSET + 8))

/*=================================================================*/
/* PIN Info Command Structures and variables */
/*=================================================================*/

typedef struct	_wfs_pin_status
{
	WORD			fwDevice;
	WORD			fwEncStat;
	LPSTR			lpsExtra;
} WFSPINSTATUS, * LPWFSPINSTATUS;

typedef struct	_wfs_pin_caps
{
	WORD			wClass;
	WORD			fwType;
	BOOL			bCompound;
	USHORT		usKeyNum;
	WORD			wAlgorithms;
	WORD			wPinFormats;
	WORD			wDisplay;
	WORD			wKeyType;
	BOOL			bIDConnect;
	LPSTR			lpsValidationAlgorithms;
	LPSTR			lpsExtra;
} WFSPINCAPS, * LPWFSPINCAPS;

typedef struct	_wfs_pin_key_detail
{
	LPSTR			lpsKeyName;
	WORD			wType;
	WORD			fwUse;
	WORD			wStatus;
} WFSPINKEYDETAIL, * LPWFSPINKEYDETAIL;
             
/*=================================================================*/
/* PIN Execute Command Structures */
/*=================================================================*/

typedef struct	_wfs_hex_data
{
	USHORT		usLength;
	LPBYTE		lpbData;
} WFSXDATA, * LPWFSXDATA;

typedef struct	_wfs_pin_crypt
{
	WORD			wMode;
	LPSTR			lpsKey;
	LPWFSXDATA		lpxKeyEncKey;
	WORD			wAlgorithm;
	LPWFSXDATA		lpxStartValue;
	BYTE			bPadding;
	BOOL			bCompression;
	LPWFSXDATA		lpxCryptData;
} WFSPINCRYPT, * LPWFSPINCRYPT;

typedef struct	_wfs_pin_generate
{
	LPSTR			lpsKey;
	LPSTR			lpsEncKey;
	LPWFSXDATA		lpxIdent;
} WFSPINGENERATE, * LPWFSPINGENERATE;

typedef struct	_wfs_pin_import
{
	LPSTR			lpsKey;
	LPSTR			lpsEncKey;
	LPWFSXDATA		lpxIdent;
	LPWFSXDATA		lpxValue;
} WFSPINIMPORT, * LPWFSPINIMPORT;

typedef struct	_wfs_pin_getpin
{
	USHORT		usMaxLen;
	USHORT		usMinLen;
	BOOL			bLeadingZero;
	BOOL			bAutoEnd;
	CHAR			cEcho;
} WFSPINGETPIN, * LPWFSPINGETPIN;

typedef struct	_wfs_pin_entry
{
	USHORT		usDigits;
	WORD			wCompletion;
} WFSPINENTRY, * LPWFSPINENTRY;

typedef struct	_wfs_pin_validate
{
	LPSTR			lpsValidationData;
	LPSTR			lpsValidationAlgorithm;
	LPWFSXDATA		lpxIdent;
} WFSPINVALIDATE, * LPWFSPINVALIDATE;

typedef struct	_wfs_pin_block
{
	LPSTR			lpsCustomerData;
	LPSTR			lpsXORData;
	BYTE			bPadding;
	WORD			wFormat;
	LPSTR			lpsKey;
	LPSTR			lpsKeyEncKey;
} WFSPINBLOCK, * LPWFSPINBLOCK;

typedef struct	_wfs_pin_getdata
{
	USHORT		usMaxLen;
	USHORT		USMinLen;
	BOOL			bNumeric;
	BOOL			bAutoEnd;
} WFSPINGETDATA, * LPWFSPINGETDATA;

typedef struct	_wfs_pin_data
{
	LPSTR			lpsData;
	WORD			wCompletion;
} WFSPINDATA, * LPWFSPINDATA;

typedef struct	_wfs_pin_admin
{
	LPWFSXDATA		lpxIdent;
	LPWFSXDATA		lpxKey;
} WFSPINADMIN, * LPWFSPINADMIN;

typedef struct	_wfs_pin_display
{
	LPSTR			lpsForm;
	LPSTR			lpsData;
} WFSPINDISPLAY, * LPWFSPINDISPLAY;

/*=================================================================*/
/* PIN Message Structures */
/*=================================================================*/

typedef struct	_wfs_pin_digit
{
	WORD			wCompletion;
	USHORT		usDigit;
} WFSPINDIGIT, * LPWFSPINDIGIT;


/* restore alignment */
#pragma pack(pop)

#ifdef __cplusplus
}       /*extern "C"*/
#endif

#endif	/* __INC_XFSPIN__H */
